//
//  Circle.m
//  Hit
//
//  Created by Mark Meretzky on 10/27/13.
//  Copyright (c) 2013 Mark Meretzky. All rights reserved.
//

#import "Circle.h"

@implementation Circle

- (id) initWithCenter: (CGPoint) center radius: (CGFloat) radius color: (UIColor *) c
{
	CGRect frame = CGRectMake(
		center.x - radius,
		center.y - radius,
		2 * radius,
		2 * radius
	);

	self = [super initWithFrame: frame];
	if (self) {
		// Initialization code
		self.backgroundColor = [UIColor clearColor];
		color = c;
		//Put the Circle's origin (0, 0) at the center of the Circle.
		self.bounds = CGRectMake(-radius, -radius, 2 * radius, 2 * radius);
	}
	return self;
}

/*
Every view is rectangular, and normally a point anywhere within the rectangle
counts as being in that view.  This method (which overrides a methiod of class
UIView) causes a point to count as being within a Circle only if the point is
on or within the circumference.
*/

- (BOOL) pointInside: (CGPoint) point withEvent: (UIEvent *) event
{
	//Return YES if the point is on or within the circumference.
	CGFloat radius = self.bounds.size.width / 2;
	return hypotf(point.x, point.y) <= radius;
}

- (void) touchesBegan: (NSSet *) touches withEvent: (UIEvent *) event
{
	//Put this Circle (the Circle that was touched) in front of the other
	//Circles.
	[self.superview bringSubviewToFront: self];
}

- (void) touchesMoved: (NSSet *) touches withEvent: (UIEvent *) event
{
	UITouch *touch = [touches anyObject];
	CGPoint location = [touch locationInView: self];
	CGPoint previousLocation = [touch previousLocationInView: self];

	//dx and dy are how far to move this Circle.
	CGFloat dx = location.x - previousLocation.x;
	CGFloat dy = location.y - previousLocation.y;

	self.center = CGPointMake(self.center.x + dx, self.center.y + dy);
}


// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.

- (void) drawRect: (CGRect) rect
{
	// Drawing code
	CGContextRef c = UIGraphicsGetCurrentContext();
	CGContextBeginPath(c);
	CGContextAddEllipseInRect(c, self.bounds);

	//Break the color instance variable into 4 numbers.
	CGFloat red, green, blue, alpha;
	[color getRed: &red green: &green blue: &blue alpha: &alpha];
	CGContextSetRGBFillColor(c, red, green, blue, alpha);

	CGContextFillPath(c);
}

@end
